/*----------------------------------------------------------------------------*/
/* Teknisa Sistemas Integrados                                                */
/* 6703_ORESTPS_GERA_RETIRADA_ORCA.SQL                                        */
/* Autor: Diego Gonalves                                                     */
/* Data: 26/01/2010                                                           */
/* Descrio:                                                                 */
/*    Buscar os produtos da tabela de pedidos e fazer retiarada dos mesmos    */
/*  de acordo com o parmetrizado na tela parmetros de matria prima         */
/*----------------------------------------------------------------------------*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'GERA_RETIRADA_ORCA ' AND
                 TYPE = 'P' 		      AND
	              U.UID = O.UID           AND
	              U.NAME = USER)
DROP PROCEDURE GERA_RETIRADA_ORCA
GO

CREATE PROCEDURE GERA_RETIRADA_ORCA (@P_CDFILIAL         VARCHAR(4),
                                     @P_NRRETIRADAORE    VARCHAR(10),
                                     @P_DTSAIDINI        DATETIME,
                                     @P_DTSAIDFIN        DATETIME,
                                     @P_NRORCAINI        VARCHAR(10),
                                     @P_NRORCAFIN        VARCHAR(10),
                                     @P_CDCLIENTE        VARCHAR(21),
                                     @P_TPEVENTO         VARCHAR(03),
                                     @P_TPSERVEVEN       VARCHAR(03),
                                     @P_CDOPERADOR       VARCHAR(12),
                                     @P_DTATUAL          DATETIME)
AS
BEGIN
   DECLARE @V_DTCORRENT      DATETIME;
   DECLARE @V_TNRORCAEVENTO  VARCHAR(1);
   DECLARE @V_TCDCLIENTE     VARCHAR(1);
   DECLARE @V_TTPSERVEVEN    VARCHAR(1);
   DECLARE @V_TTPEVENTO      VARCHAR(1);
   DECLARE @V_CDPRODUTO      VARCHAR(10);
   DECLARE @V_QTITEMPED      DOUBLE PRECISION;
   DECLARE @V_NRPEDIDO       VARCHAR(10); 
   DECLARE @V_NRITEMPED      VARCHAR(10);

   SET @V_DTCORRENT     = GETDATE();
   SET @V_TNRORCAEVENTO = '';
   SET @V_TCDCLIENTE    = '';
   SET @V_TTPSERVEVEN   = '';
   SET @V_TTPEVENTO     = '';

   IF ((@P_NRORCAINI IS NULL) AND (@P_NRORCAFIN IS NULL)) BEGIN
      SET @V_TNRORCAEVENTO = 'T';
   END
   ELSE BEGIN
      SET @V_TNRORCAEVENTO = '';
   END;

   IF (@P_CDCLIENTE IS NULL) BEGIN
      SET @V_TCDCLIENTE = 'T';
   END
   ELSE BEGIN
      SET @V_TCDCLIENTE = '';
   END;

   IF (@P_TPSERVEVEN IS NULL) BEGIN
      SET @V_TTPSERVEVEN = 'T';
   END
   ELSE BEGIN
      SET @V_TTPSERVEVEN = '';
   END;

   IF (@P_TPEVENTO IS NULL) BEGIN
      SET @V_TTPEVENTO = 'T';
   END
   ELSE BEGIN
      SET @V_TTPEVENTO = '';
   END;

   INSERT INTO RETIRADAORE (CDFILIAL, NRRETIRADAORE, CDOPERADOR, DTINIEVERETIORE,
                            DTFINEVERETIORE, DTRETIRADAORE)
                    VALUES (@P_CDFILIAL, @P_NRRETIRADAORE, @P_CDOPERADOR, @P_DTSAIDINI,
                            @P_DTSAIDFIN, @V_DTCORRENT);

   DECLARE C_REG CURSOR FOR
       SELECT IP.CDPRODUTO, IP.QTITEMPED, IP.NRPEDIDO, IP.NRITEMPED
         FROM PEDIDO P, ITEMPEDIDO IP, DEPARTAMENTO DP,
               ORCAEVENTO O LEFT JOIN DEGUSTACAO DG ON (O.CDFILIAL     = DG.CDFILIAL AND
                                                        O.NRORCAEVENTO = DG.NRORCAEVENTO AND
                                                        O.NRSEQORCAEVE = DG.NRSEQORCAEVE)
        WHERE P.CDFILIAL     = @P_CDFILIAL
          AND ((P.NRORCAEVENTO BETWEEN @P_NRORCAINI AND @P_NRORCAFIN) OR (@V_TNRORCAEVENTO = 'T'))
          AND ((O.IDTPORCAEVEN = 'O' AND ( (O.IDSITUORCEVE IN ('4', '5', '6') AND (CONVERT(DATETIME, CONVERT(VARCHAR, O.DTEVENTO, 103), 103) BETWEEN @P_DTSAIDINI AND @P_DTSAIDFIN)) OR ( NOT(O.IDSITUORCEVE IN ('7', '8')) AND (CONVERT(DATETIME, CONVERT(VARCHAR, DG.DTDEGUSTACAO, 103), 103) BETWEEN @P_DTSAIDINI AND @P_DTSAIDFIN)))) OR
              (O.IDTPORCAEVEN = 'E' AND (CONVERT( DATETIME, CONVERT(VARCHAR, O.DTHRENTROREV, 103), 103) BETWEEN @P_DTSAIDINI AND @P_DTSAIDFIN)))
          AND ((CHARINDEX(O.CDCLIENTE, @P_CDCLIENTE     ) > 0 ) OR (@V_TCDCLIENTE  = 'T'))
          AND ((CHARINDEX(O.CDTPSERVEVEN, @P_TPSERVEVEN ) > 0 ) OR (@V_TTPSERVEVEN = 'T'))
          AND ((CHARINDEX(O.CDTIPOEVENTO, @P_TPEVENTO   ) > 0 ) OR (@V_TTPEVENTO   = 'T'))
          AND P.NRPEDIDO     = IP.NRPEDIDO
          AND P.CDFILIAL     = IP.CDFILIAL
          AND P.CDFILIALORC  = O.CDFILIAL
          AND P.NRORCAEVENTO = O.NRORCAEVENTO
          AND P.NRSEQORCAEVE = O.NRSEQORCAEVE
          AND DP.IDTIPODEPTO = 'P'
          AND DP.CDDEPTO     = P.CDDEPTO
        ORDER BY IP.NRPEDIDO, IP.NRITEMPED
   OPEN C_REG;
   FETCH NEXT FROM C_REG INTO @V_CDPRODUTO, @V_QTITEMPED, @V_NRPEDIDO, @V_NRITEMPED;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      EXECUTE TEKNISA.GERA_COMPOSICAO_RETIRADA @P_CDFILIAL, @P_NRRETIRADAORE, '', @V_CDPRODUTO, @V_QTITEMPED,
                                               @P_DTATUAL, 'S', @P_CDOPERADOR, @V_NRPEDIDO, @V_NRITEMPED, '', '';

      FETCH NEXT FROM C_REG INTO @V_CDPRODUTO, @V_QTITEMPED, @V_NRPEDIDO, @V_NRITEMPED;
   END;

   CLOSE C_REG;
   DEALLOCATE C_REG;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'GERA_RETIRADA_ORCA','5.09.014';
GO
